c	Function to provide Probability AMPLITUDE for a 
c	transition starting in J,M,Om, and ending in
c	J',M',Om'.  Arguments are J, M, Om, Om', J'
c	Note that for linear polarization M does not change
c
c     Formulae taken from Bray and Hochstrasser Table I, 
c	Mol Phys, 31, 1199 (1976)
c

	real function AmpLin(J,M,Om,Omp,Jp)
	real J,M,Om,Omp,Jp,arg1,arg2,arg3,arg4,arg5,arg6

	AmpLin=0.
c	write (6,*) 'Enter Amplin'
c	write (6,*) J,M,Om,Omp,Jp
c	make a bunch of checks to see that nothing illegal will happen
	If ((M.gt.J).or.(M.lt.-J)) go to 678
	If ((M.gt.Jp).or.(M.lt.-Jp)) go to 678
	If ((J.lt.Abs(Om)).or.(Jp.lt.Abs(Omp))) go to 678
	If ((J.eq.0.).and.(Jp.eq.0.)) go to 678
	If (J.lt.0.) go to 678
	If (Jp.lt.0.) go to 678
c
c
	If (Abs(Omp-Om).le.1.0E-08) then
c	here if Delta Omega = 0
c	write (6,*) ' Delta Omega = 0'
		If (Abs(J-Jp).le.1.0E-08) then
c		here for Q branch
c	write (6,*) ' Q branch'
			AmpLin=4.*M*Om/(4.*J*(J+1.))
		Elseif (Abs(J-Jp-1).le.1.0E-08) then
c		here for P branch
c	write (6,*) ' P branch'
			arg4=M**2
			arg5=J**2
			arg6=Om**2
			arg1=arg5-arg6
			arg2=arg5-arg4
			arg3=16.*(J**2)*(2.*J-1.)*(2.*J+1.)
c	write(6,*) ' arg3=',arg3
c	write (6,*) ' j=',j,' om=',om,' m=',m
c	write (6,*) ' J**2=',J**2,' Om**2=',Om**2,' M**2=',M**2
			If ((2.*J-1.).le.1.0E-08) then
				write(6,*) ' 2J-1 le 0 in AmpLin'
				stop
			Elseif ((arg1.lt.0.).or.(arg2.lt.0.))then
				write(6,*) ' J**2-Om**2 or J**2-M**2 neg'
				stop
			Endif
c	write (6,*) ' calculating amplin'
			AmpLin=4.*sqrt(arg1*arg2)/sqrt(arg3)
c	stop
c
		Elseif (Abs(J-Jp+1).le.1.0E-08) then
c		here for R branch
c	write (6,*) ' R branch'
			Amplin=4.*sqrt((J+Om+1.)*(J-Om+1.)*(J-M+1.)*(J+M+1.))/
	&		sqrt(16.*(J+1.)**2*(2.*J+1.)*(2.*J+3.))
		Else
			Write (6,*) 'Delta J too large!'
			stop
		Endif
c
c
	Elseif (Abs(Omp-Om-1.0).le.1.0E-08) then
c	here if Delta Omega =1
		If (Abs(J-Jp).le.1.0E-08) then
c		here for Q branch
			Amplin=2.*sqrt(2.)*M*sqrt((J-Om)*(J+Om+1))/(4.*J*(J+1.))
		Elseif (Abs(J-Jp-1).le.1.0E-08) then
c		here for P branch
			If ((2.*J-1.).le.1.0E-08) then
				write(6,*) ' 2J-1 le 0 in AmpLin'
				stop
			Elseif (((J**2-Om**2).lt.0.).or.((J**2-M**2).lt.0.))then
				write(6,*) ' J**2-Om**2 or J**2-M**2 neg'
				stop
			Elseif(((J-Om).lt.0.).or.((J-Om-1.).lt.0.)) then
				write(6,*) 'J-Om or J-Om-1 lt 0.'
				stop
			Endif
			Amplin=2.*sqrt(2.)*sqrt((J**2-M**2)*(J-Om)*(J-Om-1.))/
	&		sqrt(16.*J**2*(2.*J-1.)*(2.*J+1))
		Elseif (Abs(J-Jp+1).le.1.0E-08) then
c		here for R branch
			Amplin=-2.*sqrt(2.)*sqrt((J+M+1.)*(J-M+1.)*
	&		(J+Om+1.)*(J+Om+2))/
	&		sqrt(16.*(J+1.)**2*(2.*J+1.)*(2.*J+3.))
		Else
			Write (6, *) 'Delta J too large!'
			stop
		Endif
c
c
	Elseif (Abs(Omp-Om+1.0).le.1.0E-08) then
c	here if Delta Omega = -1
		If (Abs(J-Jp).le.1.0E-08) then
c		here for Q branch
			Amplin=2.*sqrt(2.)*M*sqrt((J+Om)*(J-Om+1))/(4.*J*(J+1.))		 
		Elseif (Abs(J-Jp-1).le.1.0E-08) then
c		here for P branch
			If ((2.*J-1.).le.1.0E-08) then
				write(6,*) ' 2J-1 le 0 in AmpLin'
				stop
			Elseif (((J**2-Om**2).lt.0.).or.((J**2-M**2).lt.0.))then
				write(6,*) ' J**2-Om**2 or J**2-M**2 neg'
				stop
			Endif
			Amplin=-2.*sqrt(2.)*sqrt((J**2-M**2)*(J+Om)*(J+Om-1.))/
	&		sqrt(16.*J**2*(2.*J-1.)*(2.*J+1))
		Elseif (Abs(J-Jp+1).le.1.0E-08) then
c		here for R branch
			Amplin=2.*sqrt(2.)*sqrt((J+M+1.)*(J-M+1.)*
	&		(J-Om+1.)*(J-Om+2))/
	&		sqrt(16.*(J+1.)**2*(2.*J+1.)*(2.*J+3.))
		Else
c			Write (6, *) 'Delta J too large!'
c			stop
			Amplin=0.
		Endif
	Else
c		Write (6,*) 'Delta Omega too large!'
c		stop
		Amplin=0.
	Endif
678	continue
c	write(6,*) 'exit Amplin'
	return
	end
