!	CohHiJ is the function called
c
c
c
c
	Real function CohHiJ(Jin,Min,Pin,Fin,Theta,xnu)
c
c	This function does a coherent summation of all the final
c	states from a given initial state (Ji,Mi,Pi,Fi) weighted by 
c	a complex broadening factor (determined in function FL(xnu,...) ),
c	multiplies the sum by a wavefunction for producing fragments
c	at angle theta, and then multiplies the result by its complex
c	conjugate to return a probability.
c
c
c
c
	real Jin,Min,Pin,Fin,Theta,xnu
	real Jfin,Mfin,Pfin,Ffin,Jfbot
	real Prob,dnorm,Twave
	real Omin,Omfin,Omx
	complex FL,zprob,Tamp,xFL
c
	include 'Spectra.f'
c
c
c
c	This routine corrects for HighJ values where we cannot accurately
c	calculate d(J,N,M,theta).  What we want here is the amplitudes for the
c	P,Q,R branch transitions for the real J, but with the angular distribution
c	evaluated as if J were Jcalc, the maximum value that we can calculate 
c	accurately.  
c
c	write (6,*) ' Entered CohHiJ'
	If (icntrl.eq.1) then
		Prob=Spect(Jin,Min,Pin,Fin,Theta,xnu)
		go to 1000
	endif
c
c	
c	this is for linear polarization so
	Mfin=Min
c

c
c	This is the change made July 2007 to fix parity problems
c	(added the next two lines)
	Prob=0.
	Do 200 omx=-ommaxfin, ommaxfin, 1
c
c	sum over final J levels
	zprob=cmplx(0.,0.)
c
c	prevent a P(0) line, which screws up dnorm
	Jfbot=Jin-1.
	If (Jfbot.lt.0.) Jfbot=Jin
	do 100 Jfin=Jfbot,Jin+1.,1.
c	add a variable here for High J correction
	iJfin=Jfin-Jin
c
c	dnorm is a normalization factor for the d matrix elements
c
c	dnorm=sqrt( (2.*Jfin+1.)/2.	)
c	This is different for the High J part:
	dnorm=sqrt( (2.*(Jcalc+iJfin)+1.)/2.	)
c
c
c	sum over M states
c		we don't sum over final M states because Mfin=Min
c		for linear polarization.  For circular polarization
c		this would need to be changed
c
c	sum over final parity states
c	instead of a loop, we just choose Pfin
c	the initial and dissociative states are of opposite parity
c		for a dipole allowed transition
	Pfin=-Pin
c
c	sum over final F levels
	do 100 Ffin=Ffstart,Ffend,1.
c
	xFL=FL(xnu,Jin,Pin,Fin,Jfin,Pfin,Ffin)
c
c	
c	write (6,*) ' ***** Jin= ',Jin,'  Jfin= ',Jfin
c	write (6,*) ' Pin,Pfin = ',Pin,Pfin
c	write (6,*) ' Fin,Ffin = ',Fin,Ffin
c	write (6,*) ' FL= ',FL(xnu,Jin,Pin,Fin,Jfin,Pfin,Ffin)
c
c	Step One: calculate the complex transition amplitude
	Tamp=cmplx(0.,0.)
c	Sum over Omin and Omfin; note that ain,ax will assign 0 to 
c	inappropriate vallues of Omin and Omfin (e.g. Omin=0 for a doublet pi)
	do 51 Omin=-Ommaxin,Ommaxin,1.
	do 50 Omfin=-Ommaxfin,Ommaxfin,1.
c	write (6,*) ' Min,Omin,Omfin=', Min,Omin,Omfin
c	write (6,*) ' ain  = ',ax(Jin,Pin,Fin,Omin,0)
c	write (6,*) ' afin = ',ax(Jfin,Pfin,Ffin,Omfin,1)
c	write (6,*) ' amplin=',Amplin(Jin,Min,Omin,Omfin,Jfin)
c	pause
c
	Tamp=Tamp+
	&	xFL*
	&	cmplx(
	&	Xaxl(Jin,Pin,Fin,Omin)*XAmplin(Jin,Min,Omin,Omfin,Jfin)*
	&	Xaxu(Jfin,Pfin,Ffin,Omfin)
	&	,0.)
50	continue
51	continue
c	go to step two of calculation
c	write (6,*) ' Tamp= ',Tamp
c
c
c
c
c	Step Two: calculate the angular part of the final
c	scattering wavefunction
c
	Twave=0.
c	Sum over  Omfin; note that ax (Xaxl,Xaxu) will assign 0 to 
c	inappropriate vallues of Omfin (e.g. Omfin=0 for a doublet pi)
c	The next loop was removed July 2007 to fix parity error
c	do 60 Omx=-Ommaxfin,Ommaxfin,1.
c	write (6,*) ' dnorm= ',dnorm
c	write (6,*) ' afin= ',ax(Jfin,Pfin,Ffin,Omfin,1)
c	write (6,*) ' DD =  ',DD(Jfin,Omfin,Mfin,theta)
c	write (6,*) ' D  =  ',D(Jfin,Omfin,Mfin,theta)
c	write (6,*) ' Twave init=', Twave
c
c
c	Here's the tricky part for the High J calculation.  Nearly everything so far
c	has been what it would be normally, but here we cant use Jfin in XD 
c	because XD is not accurate.  Note that it will occur that Mfin is larger
c	than Jcalc, but XD returns zero in those cases.  Note also that amplitude 
c	Xaxu (ax(...,1)) is the real amplitude of the High J upper state.  Thus, 
c	real effect of this approx is to limit d(J,N,M,theta). Note that 
c	XD has an input J that is different for P,Q,R, and that the amplitude is that
c	for the real (High J) state, with proper parity etc. 
	Twave=Twave+
c	&	dnorm*Xaxu(Jfin,Pfin,Ffin,Omx)*XD(Jfin,Omx,Mfin,theta)
	&	dnorm*Xaxu(Jfin,Pfin,Ffin,Omx)*XD(Jcalc+iJfin,Omx,Mfin,theta)
60	continue
c	go to step three of calculation
c	write (6,*) ' Twave final = ',Twave
c
c
c	Step Three: calculate the contrib to the complex prob amplitude
c	and add it to the running total
	zprob=zprob+Tamp*cmplx(Twave,0.)
100	continue
c
c	Step Four: calculate the probability
c	note that mult by the cc is done after all terms are first added
c	The next line was changed in July 2007 to fix parity problem
c	Prob=real( zprob*conjg(zprob) )
200	Prob=Prob+real( zprob*conjg(zprob) )
c
c	
1000	continue
c	write (6,*) ' Exiting CohHiJ'
c	write (6,*) ' Prob = ',Prob
c	write (6,*) ' '
c
c
	CohHiJ=Prob
	return
c
c
c
c
	end
c