!	Coherent is the function called
c
c
c
c
	Real function Coherent(Jin,Min,Pin,Fin,Theta,xnu)
c
c	This function does a coherent summation of all the final
c	states from a given initial state (Ji,Mi,Pi,Fi) weighted by 
c	a complex broadening factor (determined in function FL(xnu,...) ),
c	multiplies the sum by a wavefunction for producing fragments
c	at angle theta, and then multiplies the result by its complex
c	conjugate to return a probability.
c
c
c
c
	real Jin,Min,Pin,Fin,Theta,xnu
	real Jfin,Mfin,Pfin,Ffin,Jfbot
	real Prob,dnorm,Twave
	real Omin,Omfin,Omx
	complex FL,zprob,Tamp,xFL
c
	include 'Spectra.f'
	include 'broad.f'
c
c
c	write (6,*) ' '
c	write (6,*) ' Entered Coherent'
	If (icntrl.eq.1) then
		Prob=Spect(Jin,Min,Pin,Fin,Theta,xnu)
		go to 1000
	endif
c
c	
c	this is for linear polarization so
	Mfin=Min
c
c
c	This is the change made July 2007 to fix parity problems
c	(added the next two lines)
	Prob=0.
	Do 200 omx=-ommaxfin, ommaxfin, 1
c
c	sum over final J levels
	zprob=cmplx(0.,0.)
c
c	prevent a P(0) line, which screws up dnorm
	Jfbot=Jin-1.
	If (Jfbot.lt.0.) Jfbot=Jin
	do 100 Jfin=Jfbot,Jin+1.,1.
c	

c
c	dnorm is a normalization factor for the d matrix elements
	dnorm=sqrt( (2.*Jfin+1.)/2.	)
c
c
c	sum over M states
c		we don't sum over final M states because Mfin=Min
c		for linear polarization.  For circular polarization
c		this would need to be changed
c
c	sum over final parity states
c	instead of a loop, we just choose Pfin
c	the initial and dissociative states are of opposite parity
c		for a dipole allowed transition
	Pfin=-Pin
c
c	sum over final F levels
	do 100 Ffin=Ffstart,Ffend,1.
c
	xFL=FL(xnu,Jin,Pin,Fin,Jfin,Pfin,Ffin)
c
c	
c	write (6,*) ' ***** Jin= ',Jin,'  Jfin= ',Jfin
c	write (6,*) ' Pin,Pfin = ',Pin,Pfin
c	write (6,*) ' Fin,Ffin = ',Fin,Ffin
c	write (6,*) ' FL= ',FL(xnu,Jin,Pin,Fin,Jfin,Pfin,Ffin)
c
c	Step One: calculate the complex transition amplitude
	Tamp=cmplx(0.,0.)
c	Sum over Omin and Omfin; note that ain,ax will assign 0 to 
c	inappropriate vallues of Omin and Omfin (e.g. Omin=0 for a doublet pi)
	do 51 Omin=-Ommaxin,Ommaxin,1.
	do 50 Omfin=-Ommaxfin,Ommaxfin,1.
c	write (6,*) ' Min,Omin,Omfin=', Min,Omin,Omfin
c	write (6,*) ' ain    = ', ax(Jin,Pin,Fin,Omin,0)
c	write (6,*) ' Xaxl   = ',Xaxl(Jin,Pin,Fin,Omin)
c	write (6,*) ' afin   = ', ax(Jfin,Pfin,Ffin,Omfin,1)
c	write (6,*) ' Xaxu   = ',Xaxu(Jfin,Pfin,Ffin,Omfin)
c	write (6,*) ' amplin = ', Amplin(Jin,Min,Omin,Omfin,Jfin)
c	write (6,*) ' Xamplin= ',XAmplin(Jin,Min,Omin,Omfin,Jfin)
c	pause
	Tamp=Tamp+
	&	xFL*
	&	cmplx(
	&	Xaxl(Jin,Pin,Fin,Omin)*XAmplin(Jin,Min,Omin,Omfin,Jfin)*
	&	Xaxu(Jfin,Pfin,Ffin,Omfin)
	&	,0.)
50	continue
51	continue
c	go to step two of calculation
c	write (6,*) ' Tamp= ',Tamp
c
c
c
c
c	Step Two: calculate the angular part of the final
c	scattering wavefunction
c
c	Sum over  Omfin; note that ax (Xaxl,Xaxu) will assign 0 to 
c	inappropriate vallues of Omfin (e.g. Omfin=0 for a doublet pi)
c
c	The next loop was deleted in July 2007 to fix parity error
c	Twave=0.
c	do 60 Omx=-Ommaxfin,Ommaxfin,1.
c	write (6,*) ' Min,Omin,Omfin=', Min,Omin,Omx
c	write (6,*) ' dnorm= ',dnorm
c	write (6,*) ' afin= ',ax(Jfin,Pfin,Ffin,Omx,1)
c	write (6,*) ' Xaxu   = ',Xaxu(Jfin,Pfin,Ffin,Omx)
c	write (6,*) ' Theta = ', Theta
c	write (6,*) ' XD =  ',XD(Jfin,Omx,Mfin,theta)
c	write (6,*) ' D  =  ',D(Jfin,Omx,Mfin,theta)
c	write (6,*) ' Tamp= ',Tamp
c	write (6,*) ' Twave init=', Twave 
c	Twave=Twave+
c	&	dnorm*Xaxu(Jfin,Pfin,Ffin,Omx)*XD(Jfin,Omx,Mfin,theta)
c60	continue
	Twave=
	&	dnorm*Xaxu(Jfin,Pfin,Ffin,Omx)*XD(Jfin,Omx,Mfin,theta)

c	go to step three of calculation
c	write (6,*) ' Twave final = ',Twave
c	pause
c
c
c	Step Three: calculate the contrib to the complex prob amplitude
c	and add it to the running total
	zprob=zprob+Tamp*cmplx(Twave,0.)
c	optional write
c	if ((abs(Jin-Jfin).le.0.001).and.
c	&	  (Xaxu(Jfin,Pfin,Ffin,Omx).ge..0001).and.
c    &      (real(Tamp*conjg(Tamp)).ge.0.0001).and.
c	&      (abs(xnu-wavenum(Jin,Pin,Fin,Jfin,Pfin,Ffin)).le.0.01))then
c		write (6,*) ' '
c		write (6,*) ' Jin,Jfin=   ', Jin,Jfin
c		write (6,*) ' Min, Omfin= ', Min,omx
c		write (6,*) ' Ffin =      ', Ffin
c		write (6,*) ' wavenum=    ', xnu
c		write (6,*) ' theta=      ', theta
c		write (6,*) ' Tamp=    ', real( Tamp )
c		write (6,*) ' d(theta)=', XD(Jfin,Omx,Min,theta)
c		write (6,*) ' Xaxu =   ', Xaxu(Jfin,Pfin,Ffin,Omx)
c		write (6,*) ' zprob^2= ', real( zprob*conjg(zprob) )
c	endif
c
100	continue
c		write (6,*) 'End of 100 loop'
c		write (6,*) 'Jfin,Ffin= ',Jfin,Ffin
c		pause
c
c
f
c
c	Step Four: calculate the probability
c	note that mult by the cc is done after all terms are first added
c	The next line was changed in July 2007 to fix parity problem
c	Prob=real( zprob*conjg(zprob) )
	Prob=Prob+real( zprob*conjg(zprob) )
c		write (6,*) 'Prob=   ',Prob
200	continue
c		write (6,*) 'End of 200 Loop'
c		write (6,*) 'omx= ',omx
c
c	
1000	continue
c	write (6,*) ' Exiting Coherent'
c	write (6,*) ' Prob = ',Prob
c	write (6,*) ' '
c	pause
c
c
	Coherent=Prob
	return
c
c
c
c
	end
c