c		**************************************************
c
c
	Real function CohTest(Jin,Min,Pin,Fin,Jfin)
c
c	This function does a coherent summation of all the final
c	states from a given initial state (Ji,Mi,Pi,Fi) weighted by 
c	a complex broadening factor (determined in function FL(xnu,Jp) ),
c	multiplies the sum by a wavefunction for producing fragments
c	at angle theta, and then multiplies the result by its complex
c	conjugate to return a probability.
c
c
c
c
	real Jin,Min,Pin,Fin
	real Jfin,Mfin,Pfin,Ffin
	real Prob,Twave
	real Omin,Omfin
	complex zprob,Tamp
c
	include 'spectra.f'
c
c
c
c	write (7,*) ' Entered CohTest'
c	write (7,*) ' ***** Jin= ',Jin,'   Jfin= ',Jfin
c	
c	this is for linear polarization so
	Mfin=Min
c
c	sum over final J levels
c	do 100 Jfin=Jin-1.,Jin+1.,1.
c	don't do this here, since we want prob for an individual P,Q,or R
c
c
c	sum over M states
c		we don't sum over final M states because Mfin=Min
c		for linear polarization.  For circular polarization
c		this would need to be changed
c
c	sum over final parity states
c	instead of a loop, we just choose Pfin
c	the initial and dissociative states are of opposite parity
c		for a dipole allowed transition
	Pfin=-Pin
c
c	sum over final F levels
	do 100 Ffin=Ffstart,Ffend,1.
	
	zprob=0.


c	Step One: calculate the complex transition amplitude
	Tamp=cmplx(0.,0.)
c	Sum over Omin and Omfin; note that ain,afin will assign 0 to 
c	inappropriate vallues of Omin and Omfin (e.g. Omin=0 for a doublet pi)
	do 50 Omin=-Ommaxin,Ommaxin,1.
	do 50 Omfin=-Ommaxfin,Ommaxfin,1.
c	write (7,*) ' Pin,Pfin = ',Pin,Pfin
c	write (7,*) ' Fin,Ffin = ',Fin,Ffin
c	write (7,*) ' Min,Omin,Omfin=', Min,Omin,Omfin
c	write (7,*) ' ain  = ',ax(Jin,Pin,Fin,Omin,0)
c	write (7,*) ' afin = ',ax(Jfin,Pfin,Ffin,Omfin,1)
c	write (7,*) ' amplin=',Amplin(Jin,Min,Omin,Omfin,Jfin)
	Tamp=Tamp+
	&	cmplx(
	&	ax(Jin,Pin,Fin,Omin,0)*Amplin(Jin,Min,Omin,Omfin,Jfin)*
	&	ax(Jfin,Pfin,Ffin,Omfin,1)
	&	,0.)
c	go to step two of calculation
c
c
c
	Twave=1.
c
50	continue
c	Step Three: calculate the complex prob amplitude 
	zprob=Tamp*cmplx(Twave,0.)
c
c	Step Four: calculate the probability
	Prob=real( zprob*conjg(zprob) )
c
c	continuing looping over Jfin,Mfin,Pfin,Ffin or return
100	continue
c
c	write (7,*) ' Exiting CohTest'
c	write (7,*) ' Prob = ',Prob
c	write (7,*) ' '
	CohTest=Prob
	return
	end
c
c
c
c		*****************************************************
	subroutine test1
c
	real Jin,Min,Pin,Fin
	real Jfin
	integer ipar,iparx
	real PZ,QZ,RZ
	integer iver
c
	include 'Lookup.f'
	include 'Spectra.f'
	include	'Broad.f'
	include 'ReadCmn.f'

c
c
c
c	read information from external file and interpret it
	call readinfo
c
	dnu=0.
	T=100.
c	open file for writing results
	open (7,file='results.dat')
c	write out some stuff at the beginning of the output file
	call writehead
c
c
c
c
c	First Test Table 6.6 Zare p 286
c
c	 
c
c	these are the loops summing over all the possible initial 
c	states Jin,Min,Pin,Fin.  If the state is some linear combination
c	of omega levels, that will be dealt with in Coherent.
c
c	do different values of Jin
	do 100 Jin=Jmin,Jmax,1.

c	Calculate Zare Table values
	if (Ommaxin.eq.Ommaxfin) iver=1
	if (Ommaxin.eq.Ommaxfin-1.) iver=2
	If (Ommaxin.eq.Ommaxfin+1.) iver=3
	write (7,*) ' '
	write (7,*) ' J = ', Jin,'  iver= ',iver
	if (iver.eq.1) then
c	here for delta omega = 0 transition
	PZ= (Jin**2 - Ommaxin**2)/Jin 
	QZ= (2.*Jin+1.)*Ommaxin**2/(Jin*(Jin+1.)) 
	RZ= ((Jin+1.)**2-Ommaxin**2)/(Jin+1.)
	elseif (iver.eq.2) then
c	here for delta omega=+1 transition
	PZ=(Jin-1.-Ommaxin)*(Jin-Ommaxin)/(4.*Jin)
	QZ=(Jin+1.+Ommaxin)*(Jin-Ommaxin)*(2.*Jin+1.)/(4.*Jin*(Jin+1.))
	RZ=(Jin+2.+Ommaxin)*(Jin+1.+Ommaxin)/(4.*(Jin+1.))
	elseif (iver.eq.3) then
c	here for delta omega=-1
	PZ=(Jin-1.+Ommaxin)*(Jin+Ommaxin)/(4*Jin)
	QZ=(Jin+1.-Ommaxin)*(Jin+Ommaxin)*(2.*Jin+1.)/(4.*Jin*(Jin+1.))
	RZ=(Jin+2.-Ommaxin)*(Jin+1.-Ommaxin)/(4.*(Jin+1))
	endif
c
c
c	sum over Min
	sump=0.
	sumq=0.
	sumr=0.
	do 50 Min= -Jin,Jin,1.
c
c	sum over parity states
c	find out how many and, if only one,what it is
c	Pin is returned only if iparx=1
	call igetpar(Jin,Pin,iparx)
	do 50 ipar=1,iparx 
	if ((iparx.eq.2).and.(ipar.eq.1)) Pin=1.0
	if ((iparx.eq.2).and.(ipar.eq.2)) Pin=-1.0
c
c	sum over F levels
	do 50 Fin=Fstart,Fend,1.
c
c
c
c
c	the sum over coherently excited intermediate states
c		is done in the function Coherent, which also multiplies
c		the result by it's c.c. and returns the probability 
c		for this wavenumber (xnu) of going from the initial  
c		state to products scattered at the specified theta.
	Jfin=Jin-1.
	sump=sump+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin
	sumq=sumq+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin+1.
	sumr=sumr+CohTest(Jin,Min,Pin,Fin,Jfin)
50	continue
c
c
c	origin of factor of three is that zare considers three possible
c	dimensions in space.
c	origin of degen is that program counts both parities, whereas
c	zare table doesn't
	degen=1.
c
c	write the results to the output file
	write (7,*) 'P Tab= ',degen*PZ,'     P Exp= ',3.*sump
	write (7,*) 'Q Tab= ',degen*QZ,'     Q Exp= ',3.*sumq
	write (7,*) 'R Tab= ',degen*RZ,'     R Exp= ',3.*sumr
c
c	return to do the next value of Jin or finish
100	continue
c
c	close output
	close(7)
	return
	end
c
c
c
c		*****************************************************
	subroutine test2
c
	real Jin,Min,Pin,Fin
	real Jfin
	integer ipar,iparx
	real PZ,QZ,RZ
c
	include 'Lookup.f'
	include 'Spectra.f'
	include	'Broad.f'
	include 'ReadCmn.f'
c
c
c
c	read information from external file and interpret it
	call readinfo
c
	dnu=0.
	T=100.
c	open file for writing results
	open (7,file='results.dat')
c	write out some stuff at the beginning of the output file
	call writehead
c
c
c
c
c	Second Test Table 1 Zare p 313
c	Try it for delta omega=0
c	doublet sigma doublet sigma
c
c	 
c
c	these are the loops summing over all the possible initial 
c	states Jin,Min,Pin,Fin.  If the state is some linear combination
c	of omega levels, that will be dealt with in Coherent.
c
c	do different values of Jin
	do 100 Jin=Jmin,Jmax,1.
	write (7,*) ' '
	write (7,*) ' Jin= ',Jin
c	Calculate Zare Table values
	if (ifin.eq.iffin) then
		PZ= (2.*Jin-1.)*(2.*Jin+1.)/(4*Jin) 
		RZ= (2.*Jin+1)*(2.*Jin+3.)/(4.*(Jin+1))
	else
		QZ= (2.*Jin+1.)/(4.*Jin*(Jin+1.)) 
	endif
c
c
c	sum over Min
	sump=0.
	sumq=0.
	sumr=0.
	do 50 Min= -Jin,Jin,1.
c
c	sum over parity states
c	find out how many and, if only one,what it is
c	Pin is returned only if iparx=1
	call igetpar(Jin,Pin,iparx)
	do 50 ipar=1,iparx 
	if ((iparx.eq.2).and.(ipar.eq.1)) Pin=1.0
	if ((iparx.eq.2).and.(ipar.eq.2)) Pin=-1.0
c
c	sum over F levels
	do 50 Fin=Fstart,Fend,1.
c
c
c
c
c	the sum over coherently excited intermediate states
c		is done in the function Coherent, which also multiplies
c		the result by it's c.c. and returns the probability 
c		for this wavenumber (xnu) of going from the initial  
c		state to products scattered at the specified theta.
	if (ifin.eq.iffin) then
	Jfin=Jin-1.
	sump=sump+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin+1.
	sumr=sumr+CohTest(Jin,Min,Pin,Fin,Jfin)
	else
	Jfin=Jin
	sumq=sumq+CohTest(Jin,Min,Pin,Fin,Jfin)
	endif
50	continue
c
c
c	origin of factor of three is that zare considers three possible
c	dimensions in space.
c	origin of degen is that program counts both parities, whereas
c	zare table doesn't
c
	degen=1.
c	write the results to the output file
	if (ifin.eq.iffin) then
	write (7,*) 'P Tab= ',degen*PZ,'     P Exp= ',3.*sump
	write (7,*) 'R Tab= ',degen*RZ,'     R Exp= ',3.*sumr
	else
	write (7,*) 'Q Tab= ',degen*QZ,'     Q Exp= ',3.*sumq
	endif
c
c	return to do the next value of Jin or finish
100	continue
c
c	close output
	close(7)
	return
	end
c
c

c		*****************************************************
	subroutine test3
c
	real Jin,Min,Pin,Fin
	real Jfin
	integer ipar,iparx
	real R1JZ,Q1JZ,sumR1J,sumQ1J,P1JZ,sumP1J
c
	include 'Lookup.f'
	include 'Spectra.f'
	include	'Broad.f'
	include 'ReadCmn.f'
c
c
c
c	read information from external file and interpret it
	call readinfo
c
	dnu=0.
	T=100.
c	open file for writing results
	open (7,file='results.dat')
c	write out some stuff at the beginning of the output file
	call writehead
c
c
c
c
c	Third Test Table 2 Zare p 314
c	Try it for delta omega=1
c	doublet pi ground state to doublet sigma excited state
c
c	 
c
c	these are the loops summing over all the possible initial 
c	states Jin,Min,Pin,Fin.  If the state is some linear combination
c	of omega levels, that will be dealt with in Coherent.
c
c	do different values of Jin
	do 100 Jin=Jmin,Jmax,1.

c	Calculate Zare Table values
	Y=SOAin/Bin
	X=sqrt( (4.*(Jin+.5)**2) + (Y*(Y-4)) )
	if ((ifin.eq.1.).and.(iffin.eq.1)) then
c	test 3a
c	R1(J),P1(J+1)
	Jfin=Jin+1.
	R1JZ=(2*Jin+1.)**2 +( (2.*Jin+1.)*(4.*Jin**2+4.*Jin-7.+2.*Y)/X )
	R1JZ=R1JZ/(32.*(Jin+1.))
c	Q1(J)
	Q1JZ=(2*Jin+1.)*( (4*Jin**2+4.*Jin-1.)+
	&	((8.*Jin**3+12.*Jin**2-2.*Jin-7.+2*Y)/X) )
	Q1JZ=Q1JZ/( 32.*Jin*(Jin+1.) )
c	P1(J)
	P1JZ=(2*Jin+1.)**2 +( (2.*Jin+1.)*(4.*Jin**2+4.*Jin+1.-2.*Y)/X )
	P1JZ=P1JZ/(32.*Jin)
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
c	test 3b
	P2JZ=(2*Jin+1.)**2 +( (2.*Jin+1.)*(4.*Jin**2+4.*Jin-7.+2.*Y)/X )
	P2JZ=P2JZ/(32.*Jin)
	R2JZ=(2*Jin+1.)**2 +( (2.*Jin+1.)*(4.*Jin**2+4.*Jin+1.-2.*Y)/X )
	R2JZ=R2JZ/(32.*(Jin+1.))
	Q2JZ=(2*Jin+1.)*( (4*Jin**2+4.*Jin-1.)+
	&	((8.*Jin**3+12.*Jin**2-2.*Jin+1-2*Y)/X) )
	Q2JZ=Q2JZ/(32.*Jin*(Jin+1.))
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
c	test 3c
	R21JZ=(2*Jin+1.)**2 -( (2.*Jin+1.)*(4.*Jin**2+4.*Jin+1.-2.*Y)/X )
	R21JZ=R21JZ/(32.*(Jin+1.))
	Q21JZ=(2*Jin+1.)*( (4*Jin**2+4.*Jin-1.)-
	&	((8.*Jin**3+12.*Jin**2-2.*Jin+1-2*Y)/X) )
	Q21JZ=Q21JZ/(32.*Jin*(Jin+1.))
	P21JZ=(2*Jin+1.)**2 -( (2.*Jin+1.)*(4.*Jin**2+4.*Jin-7.+2.*Y)/X )
	P21JZ=P21JZ/(32.*Jin)
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
c	test3d
	R12JZ=(2*Jin+1.)**2 -( (2.*Jin+1.)*(4.*Jin**2+4.*Jin-7.+2.*Y)/X )
	R12JZ=R12JZ/(32.*(Jin+1.))
	Q12JZ=(2*Jin+1.)*( (4*Jin**2+4.*Jin-1.)-
	&	((8.*Jin**3+12.*Jin**2-2.*Jin-7.+2*Y)/X) )
	Q12JZ=Q12JZ/(32.*Jin*(Jin+1.))
	P12JZ=(2*Jin+1.)**2 -( (2.*Jin+1.)*(4.*Jin**2+4.*Jin+1.-2.*Y)/X )
	P12JZ=P12JZ/(32.*Jin)
	endif
c
c
c
c	sum over Min
	sumR1J=0.
	sumQ1J=0.
	sumP1J=0.
	sumR2J=0.
	sumQ2J=0.
	sumP2J=0.
	sumR21J=0.
	sumP21J=0.
	sumQ21J=0.
	sumR12J=0.
	sumP12J=0.
	sumQ12J=0.
	do 50 Min= -Jin,Jin,1.
c
c	sum over parity states
c	find out how many and, if only one,what it is
c	Pin is returned only if iparx=1
	call igetpar(Jin,Pin,iparx)
c	write (7,*) ' iparx= ',iparx
	do 50 ipar=1,iparx 
	if ((iparx.eq.2).and.(ipar.eq.1)) Pin=1.0
	if ((iparx.eq.2).and.(ipar.eq.2)) Pin=-1.0
c
c	sum over F levels
	do 50 Fin=Fstart,Fend,1.
c
c
c
c
c	the sum over coherently excited intermediate states
c		is done in the function Coherent, which also multiplies
c		the result by it's c.c. and returns the probability 
c		for this wavenumber (xnu) of going from the initial  
c		state to products scattered at the specified theta.
	if ((ifin.eq.1.).and.(iffin.eq.1)) then
c	test 3a
c	R1(J),P1(J+1)
	Jfin=Jin+1.
	sumR1J=sumR1J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin
	sumQ1J=sumQ1J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin-1.
	sumP1J=sumP1J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
c	test 3b
	Jfin=Jin+1.
	sumR2J=sumR2J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin
	sumQ2J=sumQ2J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin-1.
	sumP2J=sumP2J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
c	test 3c
	Jfin=Jin+1.
	sumR21J=sumR21J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin
	sumQ21J=sumQ21J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin-1.
	sumP21J=sumP21J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
c	test3d
	Jfin=Jin+1.
	sumR12J=sumR12J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin
	sumQ12J=sumQ12J+CohTest(Jin,Min,Pin,Fin,Jfin)
	Jfin=Jin-1.
	sumP12J=sumP12J+CohTest(Jin,Min,Pin,Fin,Jfin)
	endif


50	continue
c
c
c	origin of factor of three is that zare considers three possible
c	dimensions in space.
c	origin of degen is that program counts both parities, whereas
c	zare table doesn't
	degen=4.

c	write the results to the output file
	write (7,*) ' Jin = ',Jin
	if ((ifin.eq.1.).and.(iffin.eq.1)) then
c	test 3a
	write (7,*) ' R1(J) Tab= ',degen*R1JZ,'    R1(J) Exp= ',3.*sumR1J
	write (7,*) ' Q1(J) Tab= ',degen*Q1JZ,'    Q1(J) Exp= ',3.*sumQ1J
	write (7,*) ' P1(J) Tab= ',degen*P1JZ,'    P1(J) Exp= ',3.*sumP1J
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
c	test 3b
	write (7,*) ' R2(J) Tab= ',degen*R2JZ,'    R2(J) Exp= ',3.*sumR2J
	write (7,*) ' Q2(J) Tab= ',degen*Q2JZ,'    Q2(J) Exp= ',3.*sumQ2J
	write (7,*) ' P2(J) Tab= ',degen*P2JZ,'    P2(J) Exp= ',3.*sumP2J
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
c	test 3c
	write (7,*) ' R21(J) Tab= ',degen*R21JZ,'R21(J) Exp= ',3.*sumR21J
	write (7,*) ' Q21(J) Tab= ',degen*Q21JZ,'Q21(J) Exp= ',3.*sumQ21J
	write (7,*) ' P21(J) Tab= ',degen*P21JZ,'P21(J) Exp= ',3.*sumP21J
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
c	test3d
	write (7,*) ' R12(J) Tab= ',degen*R12JZ,'R12(J) Exp= ',3.*sumR12J
	write (7,*) ' Q12(J) Tab= ',degen*Q12JZ,'Q12(J) Exp= ',3.*sumQ12J
	write (7,*) ' P12(J) Tab= ',degen*P12JZ,'P12(J) Exp= ',3.*sumP12J
	endif
c
c	return to do the next value of Jin or finish
100	continue
c
c	close output
	close(7)
	return
	end
c

c		*****************************************************
	subroutine test4
c
	real Jin,Min,Pin,Fin
	real Jfin
	integer ipar,iparx
	real P1J,R1J,P2J,R2J,P3J,R3J,PR13J,NP13J,PQ12J,PQ23J,
	&RQ32J,RQ21J,TR31J,RP31J
	real sP1J,sR1J,sP2J,sR2J,sP3J,sR3J,sPR13J,sNP13J,sPQ12J,
	&sPQ23J,sRQ32J,sRQ21J,sTR31J,sRP31J
c
c
	include 'Lookup.f'
	include 'Spectra.f'
	include	'Broad.f'
	include 'ReadCmn.f'
c
c
c
c	read information from external file and interpret it
	call readinfo
c
	q=-10.
	g=10.
	dnu=0.
	T=100.
c	open file for writing results
	open (7,file='results.dat')
c	write out some stuff at the beginning of the output file
	call writehead
c
c
c
c
c	Fourth Test Tatum and Wilson Table 2
c	Try it for delta omega=0
c	triplet sigma minus to triplet sigma minus
c
c	 
c
c	these are the loops summing over all the possible initial 
c	states Jin,Min,Pin,Fin.  If the state is some linear combination
c	of omega levels, that will be dealt with in Coherent.
c
c	do different values of Jin
	do 100 Jin=Jmin,Jmax,1.

c	Calculate Tatum and Wilson Table values
	If ((ifin.eq.1).and.(iffin.eq.1)) then
c	test 4a
	  P1J=(1./Jin)*(   Jin*cj(Jin-1.,1)*cj(Jin,0)+
	&  sqrt((Jin-1.)*(Jin+1.))*sj(Jin-1.,1)*sj(Jin,0)  )**2
	  R1J= (1./(Jin+1.))*(  (Jin+1.)*cj(Jin+1.,1)*cj(Jin,0)+
	&  sqrt(Jin*(Jin+2.))*sj(Jin+1.,1)*sj(Jin,0)  )**2
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
c	test 4b
	  P2J=(1./Jin)*(Jin-1.)*(Jin+1.)
	  R2J=Jin*(Jin+2.)/(Jin+1.)
	elseif ((ifin.eq.6).and.(iffin.eq.6)) then
c	test 4c
	  P3J=(1./(Jin))*(  (Jin)*sj(Jin-1.,1)*sj(Jin,0)+
	&  sqrt( (Jin-1.)*(Jin+1.) )*cj(Jin-1.,1)*cj(Jin,0)  )**2
	  R3J=(1./(Jin+1.))*(  (Jin+1.)*sj(Jin+1.,1)*sj(Jin,0)+
	&  sqrt( Jin*(Jin+2.) )*cj(Jin+1.,1)*cj(Jin,0)  )**2
	elseif ((ifin.eq.6).and.(iffin.eq.1)) then
c	test 4d
	  PR13J=(1./(Jin+1.))*(  (Jin+1.)*cj(Jin+1.,1)*sj(Jin,0)-
	&  sqrt( Jin*(Jin+2.) )*sj(Jin+1.,1)*cj(Jin,0)  )**2
	  NP13J=(1./(Jin))*(  (Jin)*cj(Jin-1.,1)*sj(Jin,0)-
	&  sqrt( (Jin-1.)*(Jin+1.) )*sj(Jin-1.,1)*cj(Jin,0)  )**2
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
c	test 4e
	  PQ12J=( (2.*Jin+1.)*sj(Jin,1)**2 )/(Jin*(Jin+1.))
	elseif ((ifin.eq.6).and.(iffin.eq.4)) then
c	test 4f
	  PQ23J=( (2.*Jin+1.)*cj(Jin,0)**2 )/(Jin*(Jin+1.))
	elseif ((ifin.eq.4).and.(iffin.eq.6)) then
c	test 4g
	  RQ32J=( (2.*Jin+1.)*cj(Jin,1)**2 )/(Jin*(Jin+1.))
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
c	test 4h
	  RQ21J=( (2.*Jin+1.)*sj(Jin,0)**2 )/(Jin*(Jin+1.))
	elseif ((ifin.eq.1).and.(iffin.eq.6)) then
c	test 4i
	  TR31J=(1./(Jin+1.))*(  (Jin+1.)*sj(Jin+1.,1)*cj(Jin,0)-
	&  sqrt( Jin*(Jin+2.) )*cj(Jin+1.,1)*sj(Jin,0)  )**2
	  RP31J=(1./(Jin))*(  (Jin)*sj(Jin-1.,1)*cj(Jin,0)-
  	&  sqrt( (Jin-1.)*(Jin+1.) )*cj(Jin-1.,1)*sj(Jin,0)  )**2
	endif
c
c
c
c	sum over Min
	sP1J=0.
	sR1J=0.
	sP2J=0.
	sR2J=0.
	sP3J=0.
	sR3J=0.
	sPR13J=0.
	sNP13J=0.
	sPQ12J=0.
	sPQ23J=0.
	sRQ32J=0.
	sRQ21J=0.
	sTR31J=0.
	sRP31J=0.
c
c
	do 50 Min= -Jin,Jin,1.
c
c	sum over parity states
c	find out how many and, if only one,what it is
c	Pin is returned only if iparx=1
	call igetpar(Jin,Pin,iparx)
	do 50 ipar=1,iparx 
	if ((iparx.eq.2).and.(ipar.eq.1)) Pin=1.0
	if ((iparx.eq.2).and.(ipar.eq.2)) Pin=-1.0
c
c	sum over F levels
	do 50 Fin=Fstart,Fend,1.
c
c
c
c
c	the sum over coherently excited intermediate states
c		is done in the function Coherent, which also multiplies
c		the result by it's c.c. and returns the probability 
c		for this wavenumber (xnu) of going from the initial  
c		state to products scattered at the specified theta.
	If ((ifin.eq.1).and.(iffin.eq.1)) then
c	test 41
	  Jfin=Jin+1.
	  sR1J=sR1J+CohTest(Jin,Min,Pin,Fin,Jfin)
	  Jfin=Jin-1.
	  sP1J=sP1J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
c	test 4b
	  Jfin=Jin+1.
	  sR2J=sR2J+CohTest(Jin,Min,Pin,Fin,Jfin)
	  Jfin=Jin-1.
	  sP2J=sP2J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.6).and.(iffin.eq.6)) then
c	test 4c
	  Jfin=Jin+1.
	  sR3J=sR3J+CohTest(Jin,Min,Pin,Fin,Jfin)
	  Jfin=Jin-1.
	  sP3J=sP3J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.6).and.(iffin.eq.1)) then
c	test 4d
	  Jfin=Jin+1.
	  sPR13J=sPR13J+CohTest(Jin,Min,Pin,Fin,Jfin)
	  Jfin=Jin-1.
	  sNP13J=sNP13J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
c	test 4e
	  Jfin=Jin
	  sPQ12J=sPQ12J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.6).and.(iffin.eq.4)) then
c	test 4f
	  Jfin=Jin
	  sPQ23J=sPQ23J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.4).and.(iffin.eq.6)) then
c	test 4g
	  Jfin=Jin
	  sRQ32J=sRQ32J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
c	test 4h
	  Jfin=Jin
	  sRQ21J=sRQ21J+CohTest(Jin,Min,Pin,Fin,Jfin)
	elseif ((ifin.eq.1).and.(iffin.eq.6)) then
c	test 4i
	  Jfin=Jin+1.
	  sTR31J=sTR31J+CohTest(Jin,Min,Pin,Fin,Jfin)
	  Jfin=Jin-1.
	  sRP31J=sRP31J+CohTest(Jin,Min,Pin,Fin,Jfin)
	endif

50	continue
c
c
c	origin of factor of three is that zare considers three possible
c	dimensions in space.
c	origin of degen is that program counts both parities, whereas
c	zare table doesn't
	degen=1.
	if ((Lamin.ge.1.).or.(Lamfin.ge.1.)) degen=2.
	if ((Lamin.ge.1.).and.(Lamfin.ge.1.)) degen=4.

c	write the results to the output file
	write (7,*) ' Jin = ',Jin
	If ((ifin.eq.1).and.(iffin.eq.1)) then
	write (7,*) ' P1(J) Tab= ',degen*P1J,'    P1(J) Exp= ',3.*sP1J
	write (7,*) ' R1(J) Tab= ',degen*R1J,'    R1(J) Exp= ',3.*sR1J
	elseif ((ifin.eq.4).and.(iffin.eq.4)) then
	write (7,*) ' P2(J) Tab= ',degen*P2J,'    P2(J) Exp= ',3.*sP2J
	write (7,*) ' R2(J) Tab= ',degen*R2J,'    R2(J) Exp= ',3.*sR2J
	elseif ((ifin.eq.6).and.(iffin.eq.6)) then
	write (7,*) ' P3(J) Tab= ',degen*P3J,'    P3(J) Exp= ',3.*sP3J
	write (7,*) ' R3(J) Tab= ',degen*R3J,'    R3(J) Exp= ',3.*sR3J
	elseif ((ifin.eq.6).and.(iffin.eq.1)) then
	write (7,*) ' PR13(J) Tab= ',degen*PR13J,'PR13(J) Exp= ',3.*sPR13J
	write (7,*) ' NP13(J) Tab= ',degen*NP13J,'NP13(J) Exp= ',3.*sNP13J
	elseif ((ifin.eq.4).and.(iffin.eq.1)) then
	write (7,*) ' PQ12(J) Tab= ',degen*PQ12J,'PQ12(J) Exp= ',3.*sPQ12J
	elseif ((ifin.eq.6).and.(iffin.eq.4)) then
	write (7,*) ' PQ23(J) Tab= ',degen*PQ23J,'PQ23(J) Exp= ',3.*sPQ23J
	elseif ((ifin.eq.4).and.(iffin.eq.6)) then
	write (7,*) ' RQ32(J) Tab= ',degen*RQ32J,'RQ32(J) Exp= ',3.*sRQ32J
	elseif ((ifin.eq.1).and.(iffin.eq.4)) then
	write (7,*) ' RQ21(J) Tab= ',degen*RQ21J,'RQ21(J) Exp= ',3.*sRQ21J
	elseif ((ifin.eq.1).and.(iffin.eq.6)) then
	write (7,*) ' TR31(J) Tab= ',degen*TR31J,'TR31(J) Exp= ',3.*sTR31J
	write (7,*) ' RP31(J) Tab= ',degen*RP31J,'RP31(J) Exp= ',3.*sRP31J
	endif
c
c	return to do the next value of Jin or finish
100	continue
c
c	close output
	close(7)
	return
	end
c
c
c	  *********************************************
	subroutine testload	
c	this subroutine loads common Lookup with all the 
c	d matrix elements that will be needed for the calculation.
c	This way, they're only calculated once.
c	The routine is wasteful of space, but has the virtue of 
c	simplicity
	real J,M,N,Jstart
	integer i
c	
	include 'Lookup.f'
	include 'Spectra.f'
	include 'ReadCmn.f'
c
c
	open(8,file='testload.dat')
	Jstart=Jmin-1.
	If (Jstart.lt.0) Jstart=Jmin
	do 50 J=Jmin-1.,Jcalc+1.,1.
	do 50 N=-Ommaxfin,Ommaxfin,1.
	do 50 M=-J,J,1.
	do 50 i=1,nangdist,1
	theta=3.14159265358979*float(i-1)/float(nangdist-1)
c	write (8,*) J,N,M,theta
	write (8,*) XD(J,N,M,theta),D(J,N,M,Theta)
50	continue
	close (8)
	return
	end
c
c
c
c	************************************************************
c
c	subroutine for testing Djmn
c
c
c
c
c
	Subroutine TestDjmn
	real ang,Ji,Om,Theta,Result,sum1,sum2,Mi
	real Result1,Result2
	real*8 dpi
	integer i
	common /data/ Jdp,Jp,Fract
c
c	We're assuming Hund's case (a)
c
c
	dpi=3.1415926535897932384626433832
	write (6,*) ' Enter initial J value (F5.2):'
	read (5,*) Ji
	write (6,*) ' Enter initial M value (F5.2):'
	read(5,*) Mi
	write (6,*) ' Enter initial Om value (F5.2:'
	read(5,*) Om

c	open file for writing results
	open (8,file='angdist.dat')
c 	write (6,*) 
c	&' Enter Real integers Omega initial and Omega final (F5.2)'
c	read (5,*) Omi,Omp
c
	write (8,107) 
107	format('/*','   Theta ',1x,' Result')
c	 
c
	sum1=0.
	sum2=0.
	nangdist=500
	do 100 i=1,nangdist,1
	ang=float(i-1)*180./float(nangdist-1)
	theta=(ang/360.)*2.*dpi
	dtheta=dpi/float(nangdist)
c	The next settings are specific for the Om --> Om transition
c	and would need to be modified for others
c
	Result1=(2*Ji+1.)*d(Ji,Om,Mi,theta)*sin(theta)*dtheta*
	&d(Ji,Om,Mi,theta)/2.
	sum1=sum1+Result1
	Result2=sqrt((2*Ji+1.)*(2*(Ji+1.)+1.))*sin(theta)*dtheta*
	&d(Ji,Om,Mi,theta)*d(Ji+1.,Om,Mi,theta)/
	&2.
	sum2=sum2+Result2
	Result=d(Ji,Om,Mi,theta)*d(Ji,Om,Mi,theta)
	write(8,156) theta,Result
156	format(3x,2(e8.3,1x))
100	continue
c
c	close output
	close(8)
	write(6,*) ' Int(0-pi) sin()d()*d(J)*'
	write(6,*) ' cong(d(J))/(2J+1)=: ',sum1
	write(6,*) ' Int(0-pi) sin()d()*d(J)*'
	write(6,*) ' cong(d(J+1))/sqrt((2J+1)(2(J+1)+1))=',sum2

c
c	 
c
c
1001	return
	end
c
